Getting Started — django-frontend-skeleton 2.0.0 documentation

### Navigation

- index
- next |
- previous |
- django-frontend-skeleton 2.0.0 documentation »

# Getting Started

## Install

1. install django-frontend-skeleton (pip install, add to your requirements files, etc.)
2. add ‘djfrontend’ and ‘djfrontend.skeleton’ to your INSTALLED_APPS

## Extend

Extend the skeleton’s base template in your template(s)

    {% extends 'djfrontend/skeleton.html' %}

### Navigation

- index
- next |
- previous |
- django-frontend-skeleton 2.0.0 documentation »